# References

The following is a list of sources that were helpful or inspirational when learning new topics,
troubleshooting bugs, authoring documentation, etc.  while developing or maintaining
[this project](README.md).

- [References](#references)
  - [Markup Languages: Markdown](#markup-languages-markdown)
  - [Markup Languages: YAML](#markup-languages-yaml)
  - [Platforms: EditorConfig](#platforms-editorconfig)
  - [Platforms: `git`](#platforms-git)
  - [Platforms: `git flow`](#platforms-git-flow)
  - [Platforms: GitHub](#platforms-github)
  - [Platforms: `pre-commit`](#platforms-pre-commit)
  - [Software Engineering](#software-engineering)

## Markup Languages: Markdown

1. <https://daringfireball.net/projects/markdown/syntax>
2. <https://www.markdownguide.org/basic-syntax>
3. <https://www.markdownguide.org/cheat-sheet>

## Markup Languages: YAML

1. <https://stackoverflow.com/questions/22268952/what-is-the-difference-between-yaml-and-yml-extension>

## Platforms: EditorConfig

Examples

1. <https://github.com/jokeyrhyme/standard-editorconfig>

General

1. <https://editorconfig.org>

## Platforms: `git`

Configuration

1. <https://fileinfo.com/extension/gitattributes>
2. <https://git-scm.com/docs/gitattributes>
3. <https://git-scm.com/docs/gitignore>
4. <https://gitignore.io>

General

1. <https://git-scm.com>
2. <https://gitforwindows.org>
3. <https://github.com/git/git>

Manuals

1. <https://git-scm.com/book>

Setup

1. <https://www.atlassian.com/git/tutorials/setting-up-a-repository/git-config>
2. <https://git-scm.com/book/en/v2/Getting-Started-First-Time-Git-Setup>

Tags

1. <https://www.atlassian.com/git/tutorials/inspecting-a-repository/git-tag>

Tips & Tricks

1. <https://stackoverflow.com/questions/63241071/automate-git-merge-commit-message>

## Platforms: `git flow`

1. <https://www.atlassian.com/git/tutorials/comparing-workflows/gitflow-workflow>
2. <https://github.com/nvie/gitflow>
3. <https://gist.github.com/JamesMGreene/cdd0ac49f90c987e45ac>
4. <https://medium.com/@roalcantara/a-guide-to-improve-the-git-hub-flow-and-commits-messages-b495461e1115>
5. <https://nvie.com/posts/a-successful-git-branching-model>
6. <https://git-flow.readthedocs.io/en/latest/releases.html>

## Platforms: GitHub

Community

1. <https://docs.github.com/en/github/building-a-strong-community>

Training

1. <https://lab.github.com/githubtraining/introduction-to-github>

## Platforms: `pre-commit`

Examples

1. <https://github.com/ScribeMD/pre-commit-hooks/blob/main/.pre-commit-config.yaml>

General

1. <https://github.com/pre-commit/pre-commit>
2. <https://pre-commit.com>

## Software Engineering

Continuous Integration/Development (CI/CD)

1. <https://github.com/badges/shields>
2. <https://naereen.github.io/badges>
3. <https://shields.io/category/version>
4. <https://en.wikipedia.org/wiki/CI/CD>

Logging

1. <https://www.scalyr.com/blog/log-formatting-best-practices-readable>
2. <https://en.wikipedia.org/wiki/ISO_8601>

Versioning

1. <https://semver.org>
